@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,17 +16,23 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """Base class for Telegram Objects."""
 
-import json
+try:
+    import ujson as json
+except ImportError:
+    import json
+
 from abc import ABCMeta
 
 
 class TelegramObject(object):
-    """Base class for most telegram objects."""
+    """
+    Base class for most telegram objects.
+    """
 
     __metaclass__ = ABCMeta
+    _id_attrs = ()
 
     def __str__(self):
         return str(self.to_dict())
@@ -34,15 +40,8 @@ class TelegramObject(object):
     def __getitem__(self, item):
         return self.__dict__[item]
 
-    @staticmethod
-    def de_json(data):
-        """
-        Args:
-            data (str):
-
-        Returns:
-            telegram.TelegramObject:
-        """
+    @classmethod
+    def de_json(cls, data, bot):
         if not data:
             return None
 
@@ -53,18 +52,18 @@ class TelegramObject(object):
     def to_json(self):
         """
         Returns:
-            str:
+            :obj:`str`
         """
+
         return json.dumps(self.to_dict())
 
     def to_dict(self):
-        """
-        Returns:
-            dict:
-        """
         data = dict()
 
         for key in iter(self.__dict__):
+            if key in ('bot', '_id_attrs'):
+                continue
+
             value = self.__dict__[key]
             if value is not None:
                 if hasattr(value, 'to_dict'):
@@ -73,3 +72,13 @@ class TelegramObject(object):
                     data[key] = value
 
         return data
+
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self._id_attrs == other._id_attrs
+        return super(TelegramObject, self).__eq__(other)  # pylint: disable=no-member
+
+    def __hash__(self):
+        if self._id_attrs:
+            return hash((self.__class__, self._id_attrs))  # pylint: disable=no-member
+        return super(TelegramObject, self).__hash__()
