@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2016
+# Copyright (C) 2015-2017
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,14 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """ This module contains the Promise class """
 
+import logging
 from threading import Event
 
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
+
 class Promise(object):
     """A simple Promise implementation for the run_async decorator"""
 
@@ -30,17 +35,24 @@ class Promise(object):
         self.kwargs = kwargs
         self.done = Event()
         self._result = None
+        self._exception = None
 
     def run(self):
         try:
             self._result = self.pooled_function(*self.args, **self.kwargs)
 
-        except:
-            raise
+        except Exception as exc:
+            logger.exception('An uncaught error was raised while running the promise')
+            self._exception = exc
 
         finally:
             self.done.set()
 
+    def __call__(self):
+        self.run()
+
     def result(self, timeout=None):
         self.done.wait(timeout=timeout)
+        if self._exception is not None:
+            raise self._exception  # pylint: disable=raising-bad-type
         return self._result
